``eradiate._mode``
==================

.. automodule:: eradiate._mode

.. py:currentmodule:: eradiate._mode

Functions
---------

.. autofunction:: mode

.. autofunction:: modes

.. autofunction:: set_mode

.. autofunction:: supported_mode

.. autofunction:: unsupported_mode

Classes
-------

.. autosummary::
   :toctree: generated/autosummary/

   Mode
   SpectralMode
   MitsubaBackend
   MitsubaColorMode
